summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneyedit.h')
-rw-r--r--kmymoney2/widgets/kmymoneyedit.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmymoney2/widgets/kmymoneyedit.h b/kmymoney2/widgets/kmymoneyedit.h
index 6df557d..77c7a75 100644
--- a/kmymoney2/widgets/kmymoneyedit.h
+++ b/kmymoney2/widgets/kmymoneyedit.h
@@ -61,17 +61,17 @@ class kMyMoneyMoneyValidator : public TQDoubleValidator
public:
/**
* Constuct a locale-aware KDoubleValidator with default range
* (whatever TQDoubleValidator uses for that) and tqparent @p
* tqparent
*/
- kMyMoneyMoneyValidator( TQObject * tqparent, const char * name=0 );
+ kMyMoneyMoneyValidator( TQObject * parent, const char * name=0 );
/**
* Constuct a locale-aware KDoubleValidator for range [@p bottom,@p
* top] and a precision of @p decimals decimals after the decimal
* point.
*/
kMyMoneyMoneyValidator( double bottom, double top, int decimals,
- TQObject * tqparent, const char * name=0 );
+ TQObject * parent, const char * name=0 );
/**
* Destructs the validator.
*/
@@ -143,8 +143,8 @@ protected slots:
void slotCalculatorOpen(void);
public:
- kMyMoneyEdit(TQWidget *tqparent=0, const char *name=0, const int prec = -2);
- kMyMoneyEdit(const MyMoneySecurity& eq, TQWidget *tqparent=0, const char *name=0);
+ kMyMoneyEdit(TQWidget *parent=0, const char *name=0, const int prec = -2);
+ kMyMoneyEdit(const MyMoneySecurity& eq, TQWidget *parent=0, const char *name=0);
~kMyMoneyEdit();
/**
@@ -61,17 +61,17 @@ class kMyMoneyMoneyValidator : public TQDoubleValidator
/**
* Constuct a locale-aware KDoubleValidator with default range
- * (whatever TQDoubleValidator uses for that) and tqparent @p
- * tqparent
+ * (whatever TQDoubleValidator uses for that) and parent @p
+ * parent
*/